package sun.management;

import javax.management.openmbean.OpenDataException;
import javax.management.openmbean.CompositeDataSupport;
import javax.management.openmbean.CompositeData;
import javax.management.openmbean.CompositeType;
import java.lang.management.MonitorInfo;

public class MonitorInfoCompositeData extends LazyCompositeData
{
    private final MonitorInfo lock;
    private static final CompositeType monitorInfoCompositeType;
    private static final String[] monitorInfoItemNames;
    private static final String CLASS_NAME = "className";
    private static final String IDENTITY_HASH_CODE = "identityHashCode";
    private static final String LOCKED_STACK_FRAME = "lockedStackFrame";
    private static final String LOCKED_STACK_DEPTH = "lockedStackDepth";
    private static final long serialVersionUID = -5825215591822908529L;
    
    private MonitorInfoCompositeData(MonitorInfo lock) {
        this.lock = lock;
    }
    
    public MonitorInfo getMonitorInfo() {
        return this.lock;
    }
    
    public static CompositeData toCompositeData(MonitorInfo monitorInfo) {
        return new MonitorInfoCompositeData(monitorInfo).getCompositeData();
    }
    
    @Override
    protected CompositeData getCompositeData() {
        int length = MonitorInfoCompositeData.monitorInfoItemNames.length;
        Object[] itemValues = new Object[length];
        CompositeData compositeData = LockInfoCompositeData.toCompositeData(this.lock);
        for (int i = 0; i < length; ++i) {
            String s = MonitorInfoCompositeData.monitorInfoItemNames[i];
            if (s.equals("lockedStackFrame")) {
                StackTraceElement lockedStackFrame = this.lock.getLockedStackFrame();
                itemValues[i] = ((lockedStackFrame != null) ? StackTraceElementCompositeData.toCompositeData(lockedStackFrame) : null);
            }
            else if (s.equals("lockedStackDepth")) {
                itemValues[i] = new Integer(this.lock.getLockedStackDepth());
            }
            else {
                itemValues[i] = compositeData.get(s);
            }
        }
        try {
            return new CompositeDataSupport(MonitorInfoCompositeData.monitorInfoCompositeType, MonitorInfoCompositeData.monitorInfoItemNames, itemValues);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
    }
    
    static CompositeType getMonitorInfoCompositeType() {
        return MonitorInfoCompositeData.monitorInfoCompositeType;
    }
    
    public static String getClassName(CompositeData compositeData) {
        return LazyCompositeData.getString(compositeData, "className");
    }
    
    public static int getIdentityHashCode(CompositeData compositeData) {
        return LazyCompositeData.getInt(compositeData, "identityHashCode");
    }
    
    public static StackTraceElement getLockedStackFrame(CompositeData compositeData) {
        CompositeData compositeData2 = (CompositeData)compositeData.get("lockedStackFrame");
        if (compositeData2 != null) {
            return StackTraceElementCompositeData.from(compositeData2);
        }
        return null;
    }
    
    public static int getLockedStackDepth(CompositeData compositeData) {
        return LazyCompositeData.getInt(compositeData, "lockedStackDepth");
    }
    
    public static void validateCompositeData(CompositeData compositeData) {
        if (compositeData == null) {
            throw new NullPointerException("Null CompositeData");
        }
        if (!LazyCompositeData.isTypeMatched(MonitorInfoCompositeData.monitorInfoCompositeType, compositeData.getCompositeType())) {
            throw new IllegalArgumentException("Unexpected composite type for MonitorInfo");
        }
        return;
    }
    
    static {
        try {
            monitorInfoCompositeType = (CompositeType)MappedMXBeanType.toOpenType(MonitorInfo.class);
            monitorInfoItemNames = (String[])MonitorInfoCompositeData.monitorInfoCompositeType.keySet().toArray(new String[0]);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
    }
}
